---
name: Bug Report
about: Create a report to help us improve
title: '[BUG] '
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**

**Expected behavior**
A clear description of what you expected to happen.

**Environment:**
 - OS: [e.g. Ubuntu 20.04]
 - Python version: [e.g. 3.9]
 - WeatherFlow version: [e.g. 0.1.0]
 - PyTorch version: [e.g. 1.9.0]
